#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pointedlist
version:              0.6.1
visibility:           public
id:                   pointedlist-0.6.1-GPnNruETwr3L9QwhBhyGbg
key:                  pointedlist-0.6.1-GPnNruETwr3L9QwhBhyGbg
license:              BSD-3-Clause
maintainer:           jeffwheeler@gmail.com
author:               Jeff Wheeler
synopsis:
    A zipper-like comonad which works as a list, tracking a position.

description:
    A PointedList tracks the position in a non-empty list which works similarly
    to a zipper. A current item is always required, and therefore the list may
    never be empty.
    A circular PointedList wraps around to the other end when progressing past
    the actual edge.

category:             Data
abi:                  ff651c6b69ec8a20a32ed774923e508e
exposed:              True
exposed-modules:      Data.List.PointedList Data.List.PointedList.Circular
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pointedlist-0.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pointedlist-0.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pointedlist-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pointedlist
hs-libraries:         HSpointedlist-0.6.1-GPnNruETwr3L9QwhBhyGbg
depends:              base-4.18.2.1 binary-0.8.9.1
haddock-interfaces:   /usr/share/doc/haskell-pointedlist/html/pointedlist.haddock
haddock-html:         /usr/share/doc/haskell-pointedlist/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

